# dogesec_commons

[![codecov](https://codecov.io/gh/muchdogesec/dogesec_commons/graph/badge.svg?token=AV1IGB1GNW)](https://codecov.io/gh/muchdogesec/dogesec_commons)

## Overview

A package containing views we reuse between various DOGESEC products

User must set `STIXIFIER_NAMESPACE` in `settings.py`

To use Objects views, `dogesec_commons.objects.app.ArangoObjectsViewApp` must be added in `settings.INSTALLED_APPS`

You can see an example of it in use here:

https://github.com/muchdogesec/obstracts/blob/main/requirements.txt

## Support

[Minimal support provided via the DOGESEC community](https://community.dogesec.com/).

## License

[Apache 2.0](/LICENSE).